Unit EasyAutoStart;

{***************************************************************************

    Auteur : Jean-Baptiste DEMONTE alias FireJocker
    ( mail : jbdemonte arobas gmail.com - www.firejocker.com)

    Date : 28 Octobre 2006
    
    Description : Ce composant permet de lancer ou non l'application au demarrage de windows en l'inscrivant 
                  dans la base de registre avec la possibilit de rajouter des paramtres
                  
                  -> Plus qu'inspir par le code de Michel
    
    Proprits : ValueName : Nom de la cl qui sera stoque dans la base de registre
                 Parameter : ligne de paramtre  ajouter   ex:  -e -o -debug
                 AutoStart : lancer ou non l'application au demarrage


***************************************************************************}

Interface

Uses Windows, Classes, Registry,Forms;

Type
  TEasyAutoStart = Class(TComponent)
  Private
      FValueName : String;
      FAutoStart : Boolean;
      FParameter : String;
      procedure SetValueName(const Value: String);
      procedure SetParameter(const Value: String);
      procedure SetAutoStart(const Value: Boolean);
  Protected
      Procedure loaded; Override;
  Published
      Property ValueName :String read FValueName write SetValueName;
      Property Parameter :String read FParameter write SetParameter;
      Property AutoStart : Boolean  read FAutoStart write SetAutoStart;
  End;

procedure Register;

Implementation

  procedure Register;
  begin
    RegisterComponents('Phidels', [TEasyAutoStart]);
  end;

  Procedure TEasyAutoStart.loaded;
  Begin

      Inherited;
      If (FValueName <> '') Then
      Begin
          With TRegistry.Create do
          Begin
              RootKey := HKEY_LOCAL_MACHINE;
              FAutoStart := OpenKey('Software\Microsoft\Windows\CurrentVersion\Run\',false) and (Copy(ReadString(FValueName), 0, length(Application.ExeName) + 2) = '"' + Application.ExeName + '"');
              Free;
          End;
      End
      Else
          FAutoStart := False;
  End;

  Procedure TEasyAutoStart.SetValueName(const Value: String);
  Begin
      If (FAutoStart) Then
          With TRegistry.Create do
          Begin
              RootKey:=HKEY_LOCAL_MACHINE;
              If OpenKey('Software\Microsoft\Windows\CurrentVersion\Run', false) then
              Begin
                  // On supprime l'ancienne valeur du registre
                  If ( FValueName <> '') Then DeleteValue(FValueName);
                  // On ajoute la nouvelle
                  If ( Value <> '' ) Then WriteString(FValueName, '"' + Application.ExeName + '" ' + FParameter);
              End;
              Free;
          End;
      FValueName := Value;
  End;


  Procedure TEasyAutoStart.SetParameter(const Value: String);
  Begin
      FParameter := Value;
      // On met  jour le registre au besoin
      If ( (FAutoStart) And (FValueName <> '') ) Then
          With TRegistry.Create do
          Begin
              RootKey:=HKEY_LOCAL_MACHINE;

              if OpenKey('Software\Microsoft\Windows\CurrentVersion\Run', false) then
              Begin
                  DeleteValue(FValueName);
                  WriteString(FValueName, '"' + Application.ExeName + '" ' + FParameter);
              End;

              Free;
          End;
  End;

  Procedure TEasyAutoStart.SetAutoStart(const Value: Boolean);
  Begin
      If ( (FAutoStart <> Value) And (FValueName <> '') ) Then
          With TRegistry.Create do
          Begin
              RootKey:=HKEY_LOCAL_MACHINE;

              if OpenKey('Software\Microsoft\Windows\CurrentVersion\Run', false) then
                  If ( Value ) Then
                      WriteString(FValueName, '"' + Application.ExeName + '" ' + FParameter)
                  Else
                      DeleteValue(FValueName);

              FAutoStart := Value;
              Free;
          End;
  End;

End.
